แพคเกจนี้แสดงข้อมูลภาควิชาวิศวกรรมเกษตร
=======================================

Link: https://www.youtube.com/channel/UCWR3MwezKwOXzPSaFVtS5Iw

PyPi: https://pypi.org/project/myaekps1/

สวัสดีจ้าาาา
แพ็คนี้คือแพ็คเกจที่แสดงรายละเอียดเกี่ยวกับภาควิชาวิศวกรรมเกษตร

วิธีติดตั้ง
~~~~~~~~~~~

เปิด CMD / Terminal

.. code:: python

   pip install myaekps1

วิธีใช้งานแพ็คเพจนี้
~~~~~~~~~~~~~~~~~~~~

-  เปิด IDLE ขึ้นมาแล้วพิมพ์…

.. code:: python

   from myaekps1 import AEKPS1

   name1 = AEKPS1()
   name1.show_name()
   name1.show_youtube()
   name1.about()

พัฒนาโดย: Kaveez FB: https://www.facebook.com/kaveenon.jantra

YouTube: …
